[][src]Enum nom_supreme::error::BaseErrorKind

pub enum BaseErrorKind {
    Expected(Expectation),
    Kind(NomErrorKind),
    External(Box<dyn Error + Send + Sync + 'static>),
}

These are the different specific things that can go wrong at a particular location during a nom parse. Many of these are collected into an ErrorTree.

Variants

Expected(Expectation)

Something specific was expected, such as a specific character or any digit. See Expectation for details.

A nom parser failed.

External(Box<dyn Error + Send + Sync + 'static>)

An error outside of nom occurred during parsing; for instance, as a result of an error during map_res.